@@ -1,4 +1,15 @@
 import requests
+import spacy
+
+try:
+    nlp = spacy.load('en_core_web_sm')
+except Exception as e:
+    print(e)
+    print(str(e).split('.')[0] + "Please wait while we download the model")
+    import os
+
+    os.system('python -m spacy download en_core_web_sm')
+    nlp = spacy.load('en_core_web_sm')
 
 
 def get_temperature(json_data):
@@ -22,7 +33,9 @@ def get_weather_data(json_data, city):
     temperature = get_temperature(json_data)
     wind_speed = get_wind_speed(json_data)
     weather_details = ''
-    return weather_details + ("The weather in {} is currently {} with a temperature of {} degrees and wind speeds reaching {} km/ph".format(city, weather_type, temperature, wind_speed))
+    return weather_details + (
+        "The weather in {} is currently {} with a temperature of {} degrees and wind speeds reaching {} km/ph".format(
+            city, weather_type, temperature, wind_speed))
 
 
 def main_weather(city):
@@ -42,3 +55,23 @@ def main_weather(city):
 def weather_app(city):
     weather_res = main_weather(city)
     return weather_res
+
+
+def get_weather(text):
+    doc = nlp(text)
+    city = None
+    for ent in doc.ents:
+        city = ent.text
+
+    if city is not None:
+        return weather_app(city)
+    else:
+        url = 'http://ipinfo.io/json'
+        response = requests.get(url)
+        data = response.json()
+        city = data.get('city')
+        return weather_app(city)
+
+
+if __name__ == "__main__":
+    get_weather('what is the temperature in Delhi?')
